@@ -195,7 +195,7 @@ var popup_rendering_actor = null;
 
 var xlet_startup_error = false;
 
-var end_session_dialog = null;
+var endSessionDialog = null;
 
 var gpuOffloadHelper = null;
 var gpu_offload_supported = false;
@@ -428,8 +428,32 @@ function start() {
     windowAttentionHandler = new WindowAttentionHandler.WindowAttentionHandler();
     placesManager = new PlacesManager.PlacesManager();
 
-    if (Config.HAVE_NETWORKMANAGER)
+    // NM Agent
+    if (Config.HAVE_NETWORKMANAGER && global.settings.get_boolean("enable-nm-agent")) {
         networkAgent = new NetworkAgent.NetworkAgent();
+        global.log('NetworkManager agent: enabled')
+    }
+    else {
+        global.log('NetworkManager agent: disabled')
+    }
+
+    // Polkit Agent
+    if (global.settings.get_boolean("enable-polkit-agent")) {
+        PolkitAuthenticationAgent.init();
+        global.log('Polkit agent: enabled')
+    }
+    else {
+        global.log('Polkit agent: disabled')
+    }
+
+    // SSH Agent
+    if (global.settings.get_boolean("enable-ssh-agent")) {
+        KeyringPrompt.init();
+        global.log('SSH agent: enabled')
+    }
+    else {
+        global.log('SSH agent: disabled')
+    }
 
     magnifier = new Magnifier.Magnifier();
     locatePointer = new LocatePointer.locatePointer();
@@ -443,12 +467,6 @@ function start() {
     _initUserSession();
     screenRecorder = new ScreenRecorder.ScreenRecorder();
 
-    if (Meta.is_wayland_compositor()) {
-        PolkitAuthenticationAgent.init();
-    }
-
-    KeyringPrompt.init();
-
     _startDate = new Date();
 
     global.display.connect('restart', () => {
@@ -1583,20 +1601,21 @@ function restartCinnamon(showOsd = false) {
     global.reexec_self();
 }
 
-function show_end_session_dialog(mode) {
-    if (end_session_dialog != null) {
+function showEndSessionDialog(mode) {
+    if (endSessionDialog != null) {
         global.logWarning("End session dialog already exists");
         return;
     }
 
-    end_session_dialog = new EndSessionDialog(mode);
+    endSessionDialog = new EndSessionDialog(mode);
+    endSessionDialog.open();
 }
 
-function close_end_session_dialog() {
-    if (end_session_dialog == null) {
+function closeEndSessionDialog() {
+    if (endSessionDialog == null) {
         return;
     }
 
-    end_session_dialog.destroy();
-    end_session_dialog = null;
+    endSessionDialog.close();
+    endSessionDialog = null;
 }
